@@ -1073,16 +1073,15 @@ _EMPTY_PBAG = _PBag(_EMPTY_PMAP)
 
 ######################################## Immutable object ##############################################
 
-
-def immutable(members='', name='Immutable', verbose=False):
+def pclass(members='', name='PClass', verbose=False):
     """
-    Produces a class that either can be used standalone or as a base class for immutable classes.
+    Produces a class that either can be used standalone or as a base class for persistent classes.
 
     This is a thin wrapper around a named tuple.
 
     Constructing a type and using it to instantiate objects:
 
-    >>> Point = immutable('x, y', name='Point')
+    >>> Point = pclass('x, y', name='Point')
     >>> p = Point(1, 2)
     >>> p2 = p.set(x=3)
     >>> p
@@ -1092,7 +1091,7 @@ def immutable(members='', name='Immutable', verbose=False):
 
     Inheriting from a constructed type. In this case no type name needs to be supplied:
 
-    >>> class PositivePoint(immutable('x, y')):
+    >>> class PositivePoint(pclass('x, y')):
     ...     __slots__ = tuple()
     ...     def __new__(cls, x, y):
     ...         if x > 0 and y > 0:
@@ -1106,11 +1105,11 @@ def immutable(members='', name='Immutable', verbose=False):
     Traceback (most recent call last):
     Exception: Coordinates must be positive!
 
-    The immutable class also supports the notion of frozen members. The value of a frozen member
+    The persistent class also supports the notion of frozen members. The value of a frozen member
     cannot be updated. For example it could be used to implement an ID that should remain the same
     over time. A frozen member is denoted by a trailing underscore.
 
-    >>> Point = immutable('x, y, id_', name='Point')
+    >>> Point = pclass('x, y, id_', name='Point')
     >>> p = Point(1, 2, id_=17)
     >>> p.set(x=3)
     Point(x=3, y=2, id_=17)
@@ -1135,11 +1134,11 @@ def immutable(members='', name='Immutable', verbose=False):
 
     quoted_members = ', '.join("'%s'" % m for m in members)
     template = """
-class {class_name}(namedtuple('ImmutableBase', [{quoted_members}], verbose={verbose})):
+class {class_name}(namedtuple('PClassBase', [{quoted_members}], verbose={verbose})):
     __slots__ = tuple()
 
     def __repr__(self):
-        return super({class_name}, self).__repr__().replace('ImmutableBase', self.__class__.__name__)
+        return super({class_name}, self).__repr__().replace('PClassBase', self.__class__.__name__)
 
     def set(self, **kwargs):
         if not kwargs:
@@ -1162,7 +1161,7 @@ class {class_name}(namedtuple('ImmutableBase', [{quoted_members}], verbose={verb
         print(template)
 
     from collections import namedtuple
-    namespace = dict(namedtuple=namedtuple, __name__='pyrsistent_immutable')
+    namespace = dict(namedtuple=namedtuple, __name__='pyrsistent_pclass')
     try:
         six.exec_(template, namespace)
     except SyntaxError as e:
@@ -1170,7 +1169,8 @@ class {class_name}(namedtuple('ImmutableBase', [{quoted_members}], verbose={verb
 
     return namespace[name]
 
-
+# Deprecated alias for pclass
+immutable = pclass
 
 ## Freeze & Thaw
 
